"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import BaseModel
from typing_extensions import TypedDict


class DigitalWalletDomainTypedDict(TypedDict):
    domain_name: str
    r"""The domain to add or remove."""


class DigitalWalletDomain(BaseModel):
    domain_name: str
    r"""The domain to add or remove."""
