"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Dict, List
from typing_extensions import NotRequired, TypedDict


class PaypalOptionsTypedDict(TypedDict):
    additional_data: NotRequired[Nullable[List[Dict[str, str]]]]
    r"""Additional Set Transaction Context Values (STC) to be sent to PayPal as part of the transaction."""


class PaypalOptions(BaseModel):
    additional_data: OptionalNullable[List[Dict[str, str]]] = UNSET
    r"""Additional Set Transaction Context Values (STC) to be sent to PayPal as part of the transaction."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["additional_data"]
        nullable_fields = ["additional_data"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
